@@ -26,7 +26,7 @@
 #include "config.h"
 
 #ifdef HAVE_APP_INDICATOR
-#include <libappindicator/app-indicator.h>
+#include <libayatana-appindicator/app-indicator.h>
 #endif
 
 #define CLIPBOARD_NAME 	"UPGRADE_NOTIFIER_SELECTION"
